@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20200920';
+our $VERSION = '5.20201020';
 our %utilities;
 
 sub utilities {
@@ -1643,6 +1643,13 @@ my %delta = (
         removed => {
         }
     },
+    5.033003 => {
+        delta_from => 5.033002,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
